project = 'versioning test root'
source_suffix = {
    '.txt': 'restructuredtext'
}
exclude_patterns = ['_build']
